"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
exports.eslintBundle = eslintBundle;
var diff = _interopRequireWildcard(require("diff"));
var _eslint = require("eslint");
var _magicString = _interopRequireDefault(require("magic-string"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && Object.prototype.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
class RollupPluginESLintBundle {
  constructor(options) {
    this.name = 'rollup-plugin-eslint-bundle';
    this.options = {
      eslintOptions: {},
      ...options
    };
    this.eslintOptions = this.options.eslintOptions || {};
    this.eslint = new _eslint.ESLint(this.eslintOptions);
  }
  regenerateSourcemap(source, modifiedSource) {
    const magicString = new _magicString.default(source);
    const changes = diff.diffChars(source, modifiedSource);
    if (changes && changes.length > 0) {
      let index = 0;
      for (const part of changes) {
        const count = part.count ?? 0;
        if (part.added) {
          magicString.prependLeft(index, part.value);
          index -= count;
        } else if (part.removed) {
          magicString.remove(index, index + count);
        }
        index += count;
      }
    }
    return {
      code: magicString.toString(),
      map: magicString.generateMap({
        hires: true
      })
    };
  }
  async lint(source, sourcemap) {
    const results = await this.eslint.lintText(source);
    const result = results[0];
    const hasWarnings = result.warningCount > 0;
    const hasErrors = result.errorCount > 0;
    if (hasWarnings || hasErrors) {
      const formatter = await this.eslint.loadFormatter(this.options.formatter);
      const formattedResults = formatter.format(results);
      if (formattedResults) {
        console.log(formattedResults);
      }
    }
    const throwOnWarning = hasWarnings && this.options.throwOnWarning;
    const throwOnError = hasErrors && this.options.throwOnError;
    if (throwOnWarning && throwOnError) {
      throw new Error('Warnings or errors were found');
    } else if (throwOnWarning) {
      throw new Error('Warnings were found');
    } else if (throwOnError) {
      throw new Error('Errors were found');
    }
    const formattedSource = result.output;
    if (!formattedSource) {
      return null;
    }
    if (!sourcemap) {
      return {
        code: formattedSource
      };
    }
    return this.regenerateSourcemap(source, formattedSource);
  }
}
function eslintBundle(options) {
  const plugin = new RollupPluginESLintBundle(options);
  return {
    name: plugin.name,
    renderChunk(source, chunkInfo, outputOptions) {
      return plugin.lint(source, outputOptions.sourcemap);
    }
  };
}
var _default = exports.default = eslintBundle;
